@@ -3,9 +3,12 @@ import logging
 import sys
 
 from inspect import isawaitable
+from os import environ
+from unittest.mock import patch
 
 import pytest
 
+from sanic import Sanic
 from sanic.exceptions import SanicException
 from sanic.response import text
 
@@ -48,6 +51,7 @@ def test_asyncio_server_no_start_serving(app):
     if not uvloop_installed():
         loop = asyncio.get_event_loop()
         asyncio_srv_coro = app.create_server(
+            port=43123,
             return_asyncio_server=True,
             asyncio_server_kwargs=dict(start_serving=False),
         )
@@ -62,6 +66,7 @@ def test_asyncio_server_start_serving(app):
     if not uvloop_installed():
         loop = asyncio.get_event_loop()
         asyncio_srv_coro = app.create_server(
+            port=43124,
             return_asyncio_server=True,
             asyncio_server_kwargs=dict(start_serving=False),
         )
@@ -69,7 +74,8 @@ def test_asyncio_server_start_serving(app):
         assert srv.is_serving() is False
         loop.run_until_complete(srv.start_serving())
         assert srv.is_serving() is True
-        srv.close()
+        wait_close = srv.close()
+        loop.run_until_complete(wait_close)
         # Looks like we can't easily test `serve_forever()`
 
 
@@ -112,7 +118,7 @@ def test_app_route_raise_value_error(app):
 
 def test_app_handle_request_handler_is_none(app, monkeypatch):
     def mockreturn(*args, **kwargs):
-        return None, [], {}, "", ""
+        return None, [], {}, "", "", None
 
     # Not sure how to make app.router.get() return None, so use mock here.
     monkeypatch.setattr(app.router, "get", mockreturn)
@@ -121,11 +127,11 @@ def test_app_handle_request_handler_is_none(app, monkeypatch):
     def handler(request):
         return text("test")
 
-    request, response = app.test_client.get("/test")
+    _, response = app.test_client.get("/test")
 
     assert (
-        response.text
-        == "Error: 'None' was returned while requesting a handler from the router"
+        "'None' was returned while requesting a handler from the router"
+        in response.text
     )
 
 
@@ -144,6 +150,43 @@ def test_app_enable_websocket(app, websocket_enabled, enable):
     assert app.websocket_enabled == True
 
 
+@patch("sanic.app.WebSocketProtocol")
+def test_app_websocket_parameters(websocket_protocol_mock, app):
+    app.config.WEBSOCKET_MAX_SIZE = 44
+    app.config.WEBSOCKET_MAX_QUEUE = 45
+    app.config.WEBSOCKET_READ_LIMIT = 46
+    app.config.WEBSOCKET_WRITE_LIMIT = 47
+    app.config.WEBSOCKET_PING_TIMEOUT = 48
+    app.config.WEBSOCKET_PING_INTERVAL = 50
+
+    @app.websocket("/ws")
+    async def handler(request, ws):
+        await ws.send("test")
+
+    try:
+        # This will fail because WebSocketProtocol is mocked and only the call kwargs matter
+        app.test_client.get("/ws")
+    except:
+        pass
+
+    websocket_protocol_call_args = websocket_protocol_mock.call_args
+    ws_kwargs = websocket_protocol_call_args[1]
+    assert ws_kwargs["websocket_max_size"] == app.config.WEBSOCKET_MAX_SIZE
+    assert ws_kwargs["websocket_max_queue"] == app.config.WEBSOCKET_MAX_QUEUE
+    assert ws_kwargs["websocket_read_limit"] == app.config.WEBSOCKET_READ_LIMIT
+    assert (
+        ws_kwargs["websocket_write_limit"] == app.config.WEBSOCKET_WRITE_LIMIT
+    )
+    assert (
+        ws_kwargs["websocket_ping_timeout"]
+        == app.config.WEBSOCKET_PING_TIMEOUT
+    )
+    assert (
+        ws_kwargs["websocket_ping_interval"]
+        == app.config.WEBSOCKET_PING_INTERVAL
+    )
+
+
 def test_handle_request_with_nested_exception(app, monkeypatch):
 
     err_msg = "Mock Exception"
@@ -184,9 +227,7 @@ def test_handle_request_with_nested_exception_debug(app, monkeypatch):
     request, response = app.test_client.get("/", debug=True)
     assert response.status == 500
     assert response.text.startswith(
-        "Error while handling error: {}\nStack: Traceback (most recent call last):\n".format(
-            err_msg
-        )
+        f"Error while handling error: {err_msg}\nStack: Traceback (most recent call last):\n"
     )
 
 
@@ -206,10 +247,78 @@ def test_handle_request_with_nested_sanic_exception(app, monkeypatch, caplog):
 
     with caplog.at_level(logging.ERROR):
         request, response = app.test_client.get("/")
+    port = request.server_port
+    assert port > 0
     assert response.status == 500
-    assert response.text == "Error: Mock SanicException"
+    assert "Mock SanicException" in response.text
     assert (
         "sanic.root",
         logging.ERROR,
-        "Exception occurred while handling uri: 'http://127.0.0.1:42101/'",
+        f"Exception occurred while handling uri: 'http://127.0.0.1:{port}/'",
     ) in caplog.record_tuples
+
+
+def test_app_name_required():
+    with pytest.raises(SanicException):
+        Sanic()
+
+
+def test_app_has_test_mode_sync():
+    app = Sanic("test")
+
+    @app.get("/")
+    def handler(request):
+        assert request.app.test_mode
+        return text("test")
+
+    _, response = app.test_client.get("/")
+    assert response.status == 200
+
+
+def test_app_registry():
+    instance = Sanic("test")
+    assert Sanic._app_registry["test"] is instance
+
+
+def test_app_registry_wrong_type():
+    with pytest.raises(SanicException):
+        Sanic.register_app(1)
+
+
+def test_app_registry_name_reuse():
+    Sanic("test")
+    Sanic.test_mode = False
+    with pytest.raises(SanicException):
+        Sanic("test")
+    Sanic.test_mode = True
+    Sanic("test")
+
+
+def test_app_registry_retrieval():
+    instance = Sanic("test")
+    assert Sanic.get_app("test") is instance
+
+
+def test_get_app_does_not_exist():
+    with pytest.raises(SanicException):
+        Sanic.get_app("does-not-exist")
+
+
+def test_get_app_does_not_exist_force_create():
+    assert isinstance(
+        Sanic.get_app("does-not-exist", force_create=True), Sanic
+    )
+
+
+def test_app_no_registry():
+    Sanic("no-register", register=False)
+    with pytest.raises(SanicException):
+        Sanic.get_app("no-register")
+
+
+def test_app_no_registry_env():
+    environ["SANIC_REGISTER"] = "False"
+    Sanic("no-register")
+    with pytest.raises(SanicException):
+        Sanic.get_app("no-register")
+    del environ["SANIC_REGISTER"]
