@@ -1,14 +1,17 @@
+import asyncio
+
 import pytest
 
 from sanic.blueprints import Blueprint
 from sanic.exceptions import HeaderExpectationFailed
 from sanic.request import StreamBuffer
-from sanic.response import stream, text
+from sanic.response import json, stream, text
+from sanic.server import HttpProtocol
 from sanic.views import CompositionView, HTTPMethodView
 from sanic.views import stream as stream_decorator
 
 
-data = "abc" * 10000000
+data = "abc" * 1_000_000
 
 
 def test_request_stream_method_view(app):
@@ -329,15 +332,28 @@ def test_request_stream_handle_exception(app):
     # 404
     request, response = app.test_client.post("/in_valid_post", data=data)
     assert response.status == 404
-    assert response.text == "Error: Requested URL /in_valid_post not found"
+    assert "Requested URL /in_valid_post not found" in response.text
 
     # 405
     request, response = app.test_client.get("/post/random_id")
     assert response.status == 405
-    assert (
-        response.text == "Error: Method GET not allowed for URL"
-        " /post/random_id"
-    )
+    assert "Method GET not allowed for URL /post/random_id" in response.text
+
+
+@pytest.mark.asyncio
+async def test_request_stream_unread(app):
+    """ensure no error is raised when leaving unread bytes in byte-buffer"""
+
+    err = None
+    protocol = HttpProtocol(loop=asyncio.get_event_loop(), app=app)
+    try:
+        protocol.request = None
+        protocol._body_chunks.append("this is a test")
+        await protocol.stream_append()
+    except AttributeError as e:
+        err = e
+
+    assert err is None and not protocol._body_chunks
 
 
 def test_request_stream_blueprint(app):
@@ -616,3 +632,44 @@ def test_request_stream(app):
     request, response = app.test_client.post("/bp_stream", data=data)
     assert response.status == 200
     assert response.text == data
+
+
+def test_streaming_new_api(app):
+    @app.post("/non-stream")
+    async def handler(request):
+        assert request.body == b"x"
+        await request.receive_body()  # This should do nothing
+        assert request.body == b"x"
+        return text("OK")
+
+    @app.post("/1", stream=True)
+    async def handler(request):
+        assert request.stream
+        assert not request.body
+        await request.receive_body()
+        return text(request.body.decode().upper())
+
+    @app.post("/2", stream=True)
+    async def handler(request):
+        ret = []
+        async for data in request.stream:
+            # We should have no b"" or None, just proper chunks
+            assert data
+            assert isinstance(data, bytes)
+            ret.append(data.decode("ASCII"))
+        return json(ret)
+
+    request, response = app.test_client.post("/non-stream", data="x")
+    assert response.status == 200
+
+    request, response = app.test_client.post("/1", data="TEST data")
+    assert request.body == b"TEST data"
+    assert response.status == 200
+    assert response.text == "TEST DATA"
+
+    request, response = app.test_client.post("/2", data=data)
+    assert response.status == 200
+    res = response.json
+    assert isinstance(res, list)
+    assert len(res) > 1
+    assert "".join(res) == data
