@@ -97,9 +97,7 @@ def test_static_file_content_type(app, static_file_directory, file_name):
 def test_static_directory(app, file_name, base_uri, static_file_directory):
     app.static(base_uri, static_file_directory)
 
-    request, response = app.test_client.get(
-        uri="{}/{}".format(base_uri, file_name)
-    )
+    request, response = app.test_client.get(uri=f"{base_uri}/{file_name}")
     assert response.status == 200
     assert response.body == get_file_content(static_file_directory, file_name)
 
@@ -234,11 +232,11 @@ def test_static_content_range_invalid_unit(
     )
 
     unit = "bit"
-    headers = {"Range": "{}=1-0".format(unit)}
+    headers = {"Range": f"{unit}=1-0"}
     request, response = app.test_client.get("/testing.file", headers=headers)
 
     assert response.status == 416
-    assert response.text == "Error: {} is not a valid Range Type".format(unit)
+    assert f"{unit} is not a valid Range Type" in response.text
 
 
 @pytest.mark.parametrize("file_name", ["test.file", "decode me.txt"])
@@ -252,13 +250,11 @@ def test_static_content_range_invalid_start(
     )
 
     start = "start"
-    headers = {"Range": "bytes={}-0".format(start)}
+    headers = {"Range": f"bytes={start}-0"}
     request, response = app.test_client.get("/testing.file", headers=headers)
 
     assert response.status == 416
-    assert response.text == "Error: '{}' is invalid for Content Range".format(
-        start
-    )
+    assert f"'{start}' is invalid for Content Range" in response.text
 
 
 @pytest.mark.parametrize("file_name", ["test.file", "decode me.txt"])
@@ -272,13 +268,11 @@ def test_static_content_range_invalid_end(
     )
 
     end = "end"
-    headers = {"Range": "bytes=1-{}".format(end)}
+    headers = {"Range": f"bytes=1-{end}"}
     request, response = app.test_client.get("/testing.file", headers=headers)
 
     assert response.status == 416
-    assert response.text == "Error: '{}' is invalid for Content Range".format(
-        end
-    )
+    assert f"'{end}' is invalid for Content Range" in response.text
 
 
 @pytest.mark.parametrize("file_name", ["test.file", "decode me.txt"])
@@ -295,7 +289,7 @@ def test_static_content_range_invalid_parameters(
     request, response = app.test_client.get("/testing.file", headers=headers)
 
     assert response.status == 416
-    assert response.text == "Error: Invalid for Content Range parameters"
+    assert "Invalid for Content Range parameters" in response.text
 
 
 @pytest.mark.parametrize(
@@ -369,7 +363,7 @@ def test_file_not_found(app, static_file_directory):
     request, response = app.test_client.get("/static/not_found")
 
     assert response.status == 404
-    assert response.text == "Error: File not found"
+    assert "File not found" in response.text
 
 
 @pytest.mark.parametrize("static_name", ["_static_name", "static"])
@@ -377,20 +371,6 @@ def test_file_not_found(app, static_file_directory):
 def test_static_name(app, static_file_directory, static_name, file_name):
     app.static("/static", static_file_directory, name=static_name)
 
-    request, response = app.test_client.get("/static/{}".format(file_name))
+    request, response = app.test_client.get(f"/static/{file_name}")
 
     assert response.status == 200
-
-
-@pytest.mark.parametrize("file_name", ["test.file"])
-def test_static_remove_route(app, static_file_directory, file_name):
-    app.static(
-        "/testing.file", get_file_path(static_file_directory, file_name)
-    )
-
-    request, response = app.test_client.get("/testing.file")
-    assert response.status == 200
-
-    app.remove_route("/testing.file")
-    request, response = app.test_client.get("/testing.file")
-    assert response.status == 404
